diff libpurple/protocols/oscar/oscar_data.c @ 15822:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 5fe8042783c1
children 8bcd5840fb12
line wrap: on
line diff
--- a/libpurple/protocols/oscar/oscar_data.c	Mon Mar 19 06:11:46 2007 +0000
+++ b/libpurple/protocols/oscar/oscar_data.c	Mon Mar 19 07:01:17 2007 +0000
@@ -1,5 +1,5 @@
 /*
  * Gaim's oscar protocol plugin
  * This file is the legal property of its developers.
  * Please see the AUTHORS file distributed alongside this file.
  *
@@ -96,11 +96,11 @@
 	g_free(od->newp);
 	g_free(od->oldp);
 	if (od->icontimer > 0)
-		gaim_timeout_remove(od->icontimer);
+		purple_timeout_remove(od->icontimer);
 	if (od->getblisttimer > 0)
-		gaim_timeout_remove(od->getblisttimer);
+		purple_timeout_remove(od->getblisttimer);
 	if (od->getinfotimer > 0)
-		gaim_timeout_remove(od->getinfotimer);
+		purple_timeout_remove(od->getinfotimer);
 	while (od->oscar_connections != NULL)
 		flap_connection_destroy(od->oscar_connections->data,
 				OSCAR_DISCONNECT_DONE, NULL);
@@ -122,7 +122,7 @@
 {
 	SnacHandler *snac_handler;
 
-	gaim_debug_misc("oscar", "Adding handler for %04x/%04x\n", family, subtype);
+	purple_debug_misc("oscar", "Adding handler for %04x/%04x\n", family, subtype);
 
 	snac_handler = g_new0(SnacHandler, 1);
@@ -1,5 +1,5 @@
 /*
- * Gaim's oscar protocol plugin
+ * Purple's oscar protocol plugin
  * This file is the legal property of its developers.
  * Please see the AUTHORS file distributed alongside this file.